"use strict";
// Copyright (c) WarnerMedia Direct, LLC. All rights reserved. Licensed under the MIT license.
// See the LICENSE file for license information.
Object.defineProperty(exports, "__esModule", { value: true });
exports.createWireMockRequest = void 0;
function createWireMockRequest(request, features) {
    var _a, _b;
    const { body, cookies, headers, method, queryParameters, endpoint } = request;
    const endpointFeature = (_a = features === null || features === void 0 ? void 0 : features.requestEndpointFeature) !== null && _a !== void 0 ? _a : "url" /* Default */;
    const mock = {
        method,
    };
    mock[endpointFeature] = endpoint;
    if (body) {
        const bodyFeature = (_b = features === null || features === void 0 ? void 0 : features.requestBodyFeature) !== null && _b !== void 0 ? _b : "equalToJson" /* EqualToJson */;
        const mockBody = {};
        mockBody[bodyFeature] = body;
        mock.bodyPatterns = [mockBody];
    }
    if (cookies) {
        mock.cookies = getMockedObject(cookies, features === null || features === void 0 ? void 0 : features.requestCookieFeatures);
    }
    if (headers) {
        mock.headers = getMockedObject(headers, features === null || features === void 0 ? void 0 : features.requestHeaderFeatures);
    }
    if (queryParameters) {
        mock.queryParameters = getMockedObject(queryParameters, features === null || features === void 0 ? void 0 : features.requestQueryParamFeatures);
    }
    return mock;
}
exports.createWireMockRequest = createWireMockRequest;
/**
 * Maps cookies, headers, and queryParameters to wiremock schema
 * @param {Record<string, KeyValue>} dict
 * @param {Record<string, MatchingAttributes>} dictMatchingAttributes
 * @returns {{[p: string]: any}}
 */
function getMockedObject(dict, dictMatchingAttributes) {
    var _a;
    const mockObject = {};
    for (const key of Object.keys(dict)) {
        mockObject[key] = mapPropertyToAttribute(dict[key], (_a = dictMatchingAttributes === null || dictMatchingAttributes === void 0 ? void 0 : dictMatchingAttributes[key]) !== null && _a !== void 0 ? _a : "equalTo" /* EqualTo */);
    }
    return mockObject;
}
function mapPropertyToAttribute(value, attribute) {
    return {
        [attribute]: value,
    };
}
